@@ -3,7 +3,7 @@
   defines.h -
 
   $Author: matz $
-  $Date: 1999/08/13 05:45:03 $
+  $Date: 1999/08/24 08:21:52 $
   created at: Wed May 18 00:21:44 JST 1994
 
 ************************************************/
@@ -48,7 +48,7 @@
 #define DOSISH 1
 #endif
 
-#if defined(MSDOS) || defined(NT) || defined(__human68k__)
+#if defined(MSDOS) || defined(NT) || defined(__human68k__) || defined(OS2)
 #define PATH_SEP ";"
 #else
 #define PATH_SEP ":"
