@@ -3,7 +3,7 @@
   random.c -
 
   $Author: matz $
-  $Date: 1999/08/13 05:45:13 $
+  $Date: 1999/09/16 09:40:32 $
   created at: Fri Dec 24 16:39:21 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -12,6 +12,9 @@
 
 #include "ruby.h"
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 #include <time.h>
 #ifndef NT
 #ifdef HAVE_SYS_TIME_H
@@ -89,10 +92,11 @@ rb_f_srand(argc, argv, obj)
     static int saved_seed;
 
     if (rb_scan_args(argc, argv, "01", &seed) == 0) {
+	static int n = 0;
 	struct timeval tv;
 
 	gettimeofday(&tv, 0);
-	seed = tv.tv_sec ^ tv.tv_usec;
+	seed = tv.tv_sec ^ tv.tv_usec ^ getpid() ^ n++;
     }
     else {
 	seed = NUM2UINT(seed);
