@@ -964,7 +964,7 @@ rb_reg_s_quote(argc, argv)
 	if (*s == '[' || *s == ']'
 	    || *s == '{' || *s == '}'
 	    || *s == '(' || *s == ')'
-	    || *s == '|'
+	    || *s == '|' || *s == '-'
 	    || *s == '*' || *s == '.' || *s == '\\'
 	    || *s == '?' || *s == '+'
 	    || *s == '^' || *s == '$') {
