@@ -3,7 +3,7 @@
   string.c -
 
   $Author: matz $
-  $Date: 1999/08/13 05:45:14 $
+  $Date: 1999/09/16 09:40:33 $
   created at: Mon Aug  9 17:12:58 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -520,7 +520,7 @@ rb_str_match(x, y)
 	reg = rb_reg_regcomp(y);
 	start = rb_reg_search(reg, x, 0, 0);
 	if (start == -1) {
-	    return Qfalse;
+	    return Qnil;
 	}
 	return INT2NUM(start);
 
@@ -760,7 +760,7 @@ rb_str_upto(beg, end, excl)
     if (TYPE(end) != T_STRING) end = rb_str_to_str(end);
 
     current = beg;
-    for (;;) {
+    while (rb_str_cmp(current, end) <= 0) {
 	rb_yield(current);
 	if (!excl && rb_str_equal(current, end)) break;
 	current = rb_str_succ(current);
